AssetDeliveryPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AssetDeliveryPlatform
- Implementers
Constructors
- AssetDeliveryPlatform()
- Constructs a AssetDeliveryPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetch(
String assetPackName) → Future< void> -
fetchAssetPackState(
String assetPackName) → Future< void> -
getAssetPackPath(
{required String assetPackName, required int count, required String namingPattern, required String fileExtension}) → Future< String?> -
getAssetPackStatus(
dynamic onUpdate(Map< String, dynamic> )) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AssetDeliveryPlatform
-
The default instance of AssetDeliveryPlatform to use.
getter/setter pair